# Docums Awesome List Plugin

Docums Plugin to inject social media cards for each entry in an awesome-list. 

To use this plugin install it with pip in the same environment than Docums:

```
pip install DocumsAwesomeListPlugin
```

Then add the following entry in the Docums config file:

```yml
plugins:
  - awesome-list
```
